package com.spider.quartz.service.impl;

import java.util.List;
import com.spider.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.spider.quartz.mapper.UsUnqualifiedGoodsZhMapper;
import com.spider.quartz.domain.UsUnqualifiedGoodsZh;
import com.spider.quartz.service.IUsUnqualifiedGoodsZhService;

/**
 * 美国不合格商品展示-翻译Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-12-05
 */
@Service
public class UsUnqualifiedGoodsZhServiceImpl implements IUsUnqualifiedGoodsZhService 
{
    @Autowired
    private UsUnqualifiedGoodsZhMapper usUnqualifiedGoodsZhMapper;

    /**
     * 查询美国不合格商品展示-翻译
     * 
     * @param id 美国不合格商品展示-翻译主键
     * @return 美国不合格商品展示-翻译
     */
    @Override
    public UsUnqualifiedGoodsZh selectUsUnqualifiedGoodsZhById(Long id)
    {
        return usUnqualifiedGoodsZhMapper.selectUsUnqualifiedGoodsZhById(id);
    }

    /**
     * 查询美国不合格商品展示-翻译列表
     * 
     * @param usUnqualifiedGoodsZh 美国不合格商品展示-翻译
     * @return 美国不合格商品展示-翻译
     */
    @Override
    public List<UsUnqualifiedGoodsZh> selectUsUnqualifiedGoodsZhList(UsUnqualifiedGoodsZh usUnqualifiedGoodsZh)
    {
        return usUnqualifiedGoodsZhMapper.selectUsUnqualifiedGoodsZhList(usUnqualifiedGoodsZh);
    }

    /**
     * 新增美国不合格商品展示-翻译
     * 
     * @param usUnqualifiedGoodsZh 美国不合格商品展示-翻译
     * @return 结果
     */
    @Override
    public int insertUsUnqualifiedGoodsZh(UsUnqualifiedGoodsZh usUnqualifiedGoodsZh)
    {
        usUnqualifiedGoodsZh.setCreateTime(DateUtils.getNowDate());
        return usUnqualifiedGoodsZhMapper.insertUsUnqualifiedGoodsZh(usUnqualifiedGoodsZh);
    }

    /**
     * 修改美国不合格商品展示-翻译
     * 
     * @param usUnqualifiedGoodsZh 美国不合格商品展示-翻译
     * @return 结果
     */
    @Override
    public int updateUsUnqualifiedGoodsZh(UsUnqualifiedGoodsZh usUnqualifiedGoodsZh)
    {
        usUnqualifiedGoodsZh.setUpdateTime(DateUtils.getNowDate());
        return usUnqualifiedGoodsZhMapper.updateUsUnqualifiedGoodsZh(usUnqualifiedGoodsZh);
    }

    /**
     * 批量删除美国不合格商品展示-翻译
     * 
     * @param ids 需要删除的美国不合格商品展示-翻译主键
     * @return 结果
     */
    @Override
    public int deleteUsUnqualifiedGoodsZhByIds(Long[] ids)
    {
        return usUnqualifiedGoodsZhMapper.deleteUsUnqualifiedGoodsZhByIds(ids);
    }

    /**
     * 删除美国不合格商品展示-翻译信息
     * 
     * @param id 美国不合格商品展示-翻译主键
     * @return 结果
     */
    @Override
    public int deleteUsUnqualifiedGoodsZhById(Long id)
    {
        return usUnqualifiedGoodsZhMapper.deleteUsUnqualifiedGoodsZhById(id);
    }
}
